@@ -10,11 +10,11 @@ AnyEvent::MySQL - Pure Perl AnyEvent socket implementation of MySQL client
 
 =head1 VERSION
 
-Version 1.1.5
+Version 1.1.6
 
 =cut
 
-our $VERSION = '1.001005';
+our $VERSION = '1.001006';
 
 use AnyEvent::MySQL::Imp;
 
@@ -346,6 +346,10 @@ Please read the test.pl file as a usage example. >w<
 
     $end5->recv;
 
+    my $readonly_dbh = AnyEvent::MySQL->connect("DBI:mysql:database=test;host=127.0.0.1;port=3306", "ptest", "pass", { ReadOnly => 1 }, sub {
+      # ... we can only use "select" and "show" command on this handle
+    });
+
     $end->recv;
 
 =cut
@@ -711,6 +715,12 @@ sub _do {
     my $cb = ref($_[-1]) eq 'CODE' ? pop : \&AnyEvent::MySQL::_empty_cb;
     my($rev_dir, $dbh, $statement, $attr, @bind_values) = @_;
 
+    if( $dbh->{_}[ATTRi]{ReadOnly} && $statement !~ /^\s*(?:show|select)/i ){
+        _report_error($dbh, 'do', 1227, 'unable to perform write queries on a ReadOnly handle');
+        $cb->();
+        return;
+    }
+
     my @args = ($dbh, [TXN_TASK, sub {
         my $next_act = shift;
         AnyEvent::MySQL::Imp::send_packet($dbh->{_}[HDi], 0, AnyEvent::MySQL::Imp::COM_QUERY, _text_prepare($statement, @bind_values));
@@ -1520,12 +1530,9 @@ L<http://search.cpan.org/dist/AnyEvent-MySQL/>
 =back
 
 
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011-2014 Cindy Wang (CindyLinz).
+Copyright 2011-2015 Cindy Wang (CindyLinz).
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
@@ -1537,6 +1544,8 @@ See http://dev.perl.org/licenses/ for more information.
 
 Dmitriy Shamatrin (justnoxx@github)
 
+clking (clking@github)
+
 =cut
 
 1; # End of AnyEvent::MySQL
